@@ -13,7 +13,7 @@ from collections import deque
 import numpy as np
 from autopilot import prefs
 if prefs.AGENT.upper() == 'PILOT':
-    if 'AUDIO' in prefs.CONFIG:
+    if 'AUDIO' in prefs.CONFIG or prefs.AUDIOSERVER is not None:
         from autopilot.stim.sound import sounds
         # TODO be loud about trying to init sounds when not in config
 
