@@ -13,6 +13,9 @@ from threading import Thread
 from itertools import cycle
 from queue import Empty
 import sys
+import logging
+import os
+from datetime import datetime
 
 # importing configures environment variables necessary for importing jack-client module below
 from autopilot import external
@@ -158,6 +161,31 @@ class JackClient(mp.Process):
         globals()['CONTINUOUS_QUEUE'] = self.continuous_q
         globals()['CONTINUOUS_LOOP'] = self.continuous_loop
 
+        self.init_logging()
+        self.logger.info('Jack Client Booted')
+
+    def init_logging(self):
+        """
+        Initialize logging to a timestamped file in `prefs.LOGDIR` .
+
+        The logger name will be `'node.{id}'` .
+        """
+        #FIXME: Just copying and pasting from net node, should implement logging uniformly across hw objects
+        timestr = datetime.now().strftime('%y%m%d_%H%M%S')
+        log_file = os.path.join(prefs.LOGDIR, '{}_{}.log'.format('jack', timestr))
+
+        self.logger = logging.getLogger('jack'.format(self.name))
+        self.log_handler = logging.FileHandler(log_file)
+        self.log_formatter = logging.Formatter("%(asctime)s %(levelname)s : %(message)s")
+        self.log_handler.setFormatter(self.log_formatter)
+        self.logger.addHandler(self.log_handler)
+        if hasattr(prefs, 'LOGLEVEL'):
+            loglevel = getattr(logging, prefs.LOGLEVEL)
+        else:
+            loglevel = logging.WARNING
+        self.logger.setLevel(loglevel)
+        self.logger.info('{} Logging Initiated'.format(self.name))
+
     def boot_server(self):
         """
         Called by :meth:`.JackClient.run` to boot the server upon starting the process.
@@ -250,8 +278,7 @@ class JackClient(mp.Process):
                     data = self.continuous_q.get_nowait()
 
                 except Empty:
-                    # TODO: Logging for sound client
-                    Warning('Continuous queue was empty!')
+                    self.logger.warning('Continuous queue was empty!')
                     #self.continuous.clear()
                     data = self.zero_arr
 
@@ -280,7 +307,7 @@ class JackClient(mp.Process):
                 data = self.q.get_nowait()
             except queue.Empty:
                 data = None
-                Warning('Queue Empty')
+                self.logger.warning('Queue Empty')
             if data is None:
                 # fill with continuous noise
                 if self.continuous.is_set():
@@ -288,8 +315,7 @@ class JackClient(mp.Process):
                     try:
                         data = self.continuous_q.get_nowait()
                     except Empty:
-                        # TODO: Logging for sound client
-                        Warning('Continuous queue was empty!')
+                        self.logger.warning('Continuous queue was empty!')
                         # self.continuous.clear()
                         data = self.zero_arr
                         #self.continuous.clear()
